MultiTargetModel

Struct MultiTargetModel 

pub struct MultiTargetModel<R: Records, L> { /* private fields */ }
Merge models with single target to multi-target models

Many models assume that the target variables are uncorrelated and support therefore only a single target variable. This wrapper allows the user to merge multiple models with only a single-target variable into a multi-target model.

Implementations

Source

impl<R: Records, L> MultiTargetModel<R, L>

pub fn new(models: Vec<Box<dyn PredictInplace<R, Array1<L>>>>) -> Self

Create a wrapper model from a list of single-target models

The type parameter of the single-target models are only constraint to implement the prediction trait and can otherwise contain any object. This allows the mixture of different models into the same wrapper. If you want to use the same model for all predictions, just use the FromIterator implementation.