pub trait FromTargetArray<'a>: AsTargets {
type View;
// Required method
fn new_targets_view(
targets: ArrayView<'a, Self::Elem, Self::Ix>,
) -> Self::View;
}Expand description
Helper trait to construct counted labels
This is implemented for objects which can act as targets and created from a target matrix. For
targets represented as ndarray matrix this is identity, for counted labels, i.e.
TargetsWithLabels, it creates the corresponding wrapper struct.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.